@@ -10,8 +10,8 @@ def run(args):
   message.bright('* Building')
 
   if not os.path.exists('build'):
-    os.system('mkdir build')
+    os.makedirs('build')
   
-  cmd = 'cd build; cmake ..; make %s' % ' '.join(args)
+  cmd = 'cd build; cmake -G Ninja ..; ninja %s' % ' '.join(args)
   os.system(cmd)
   
\ No newline at end of file
